# bopt-slf

A Bayesian optimization library. It features a set level filtration and kernel learning. 

For tutorial notebooks, check out the examples folder.

## Getting started

**Installing with pip**

````
pip install bopt-slf
````

**

Read the [basic notebook](https://github.com/JavierMorlet/bopt_slf/blob/main/examples/Basic_tour.ipynb)
for an  introduction to the library.

For more details please refer to the [advaned tour notebook](https://github.com/JavierMorlet/bopt_slf/blob/main/examples/Advanced_tour.ipynb)

## Dependencies:

* numpy
* scipy
* sympy
* itertools
* pandas
* sklearn
* GPy
* prince
* properscoring
* multiprocess
* matplotlib.pyplot